require 'libxml'

module VersionOne
  class AssetRef
    attr_reader   :href, :id

    def initialize(xml_or_asset)
      case xml_or_asset
        when Asset
          @asset = xml_or_asset
          @id = @asset.id
          @href = @asset.href
        when Hash
          @id = xml_or_asset[:id]
          @href = xml_or_asset[:href]
        else
          @href = xml_or_asset.attributes['href']
          @id = xml_or_asset.attributes['idref']
      end
      raise ArgumentError, "Could not get id and href" unless @id || @href
    end

    def self.for(x)
      x.is_a?(AssetRef) ? x : AssetRef.new(x)
    end

    def get(*fields)
      @asset ||= get_asset(*fields)
    end

    def set(asset)
      case
        when !asset.is_a?(VersionOne::Asset)
          raise ArgumentError, "Parameter must be a VersionOne asset"
        when asset.id == @id
          @asset = asset
        else
          raise ArgumentError, "Asset does not match reference"
      end
    end

    def inspect
      "#<AssetRef:#{@href}>"
    end

    def to_xml
      xml = XML::Node.new('Asset')
      xml.attributes['href'] = @href if @href
      xml.attributes['idref'] = @id if @id
      xml
    end

    def method_missing(method, *args, &block)
      get.send(method, *args, &block)
    end

    private

    def get_asset(*fields)
      client = VersionOne::Client.new
      xml = client.get(href, *fields)
      Asset.new(xml: xml)
    end
  end
end
