require 'base64'
require 'logger'

module VersionOne
  class Configuration
    attr_accessor :user, :password, :service_uri

    def load(options={})
      raise ArgumentError.new("Parameter must be a hash") unless options.is_a?(Hash)

      options.each do |k,v|
        send(k.to_s + '=', v)
      end
    end

    def password_base64=(val)
      self.password=(Base64.decode64(val))
    end

  end

  def self.config
    @@config ||= Configuration.new
  end

  def self.cache
    @@cache ||= defined?(Rails) ? Rails.cache : nil
  end

  def self.cache=(c)
    @@cache = c
  end

  def self.logger=(l)
    @@logger = l
  end

  def self.logger
    @@logger ||= defined?(Rails) ? Rails.logger : create_logger
  end

  def self.create_logger
    l = Logger.new(STDOUT)
    l.level = Logger::INFO
    l
  end

end
