require 'libxml'
require 'version-one/meta/attribute_definition'

module VersionOne
  class Meta

    attr_reader :name
    attr_reader :attributes

    def initialize(xml)
      parse_xml(xml)
    end

    def self.get(asset_type, client=nil)
      client ||= VersionOne::Client.new

      xml = client.get('/meta.v1/' + asset_type, cache: {
          key: "VersionOne/meta/#{asset_type}",
          options: {
            expires_in: 60 * 60 * 24,
            race_condition_ttl: 5
          }
      })

      new(xml)
    end

    def [](name)
      @named_attributes[name]
    end

    def inspect
      '#<Meta:%s>' % [self.name]
    end

    private

    def parse_xml(xml)
      @name = xml.attributes['name']
      @attributes = []
      @named_attributes = {}

      xml.each do |child|
        next unless child.element? && (child.name == 'AttributeDefinition')
        a = AttributeDefinition.new(child)
        next if a.name == 'ID'
        @attributes << a
        @named_attributes[a.name] = a
      end

    end

  end
end
