require 'xml/libxml'

module VersionOne
  class RelationMultiValue

    def initialize(val = nil)
      @assets = {}
      @original_assets = {}
      set(val)
    end

    def <<(val)
      val = AssetRef.for(val)
      @assets[val.id] = val
    end

    def set(val)
      val ||= []
      val = [val] unless val.is_a?(Array)
      @assets = {}
      val.each do |v|
        v = AssetRef.for(v)
        @assets[v.id] = v
      end
      @original_assets ||= @assets.dup
      self
    end

    def added
      @assets.values.select{|v| !@original_assets.key?(v.id) }
    end

    def removed
      @original_assets.values.select{|v| !@assets.key?(v.id) }
    end

    def unchanged!
      @original_assets = @assets.dup
    end

    def get_all(fields=nil)
      each { |ref| ref.get(fields) }
    end

    def empty?
      @assets.empty?
    end

    def method_missing(method_name, *args, &block)
      @assets.values.send(method_name, *args, &block)
    end

    private

  end
end
